requests = [
    {
        'name': 'company',
        'params': {
                'securityId': 'Security ID of company e.g. NSE:7UP'
        }
    },
    {
        'name': 'market-data',
        'params': {
                'securityId': 'Security ID of company e.g. NSE:7UP',
                'date': 'Date for which market data is required e.g. 20170208'
        }
    },
    {
        'name': 'market-data-eod',
        'params': {
                'securityId': 'Security ID of company e.g. NSE:7UP',
                'startDate': 'Start date from which you require data e.g. 2017-03-01',
                'endDate': 'End date upto which you require data e.g. 2017-03-31'
        }
    },
    {
        'name': 'company-technicals',
        'params': {
                'securityId': 'Security ID of company e.g. NSE:7UP',
                'startDate': 'Start date from which you require data e.g. 2017-03-01',
                'endDate': 'End date upto which you require data e.g. 2017-03-31'
        }
    },
    {
        'name': 'company-financials',
        'params': {
                'securityId': 'Security ID of company e.g. NSE:7UP',
                'startDate': 'Start date from which you require data e.g. 2017-03-01',
                'endDate': 'End date upto which you require data e.g. 2017-03-31'
        }
    },
    {
        'name': 'company-returns',
        'params': {
                'securityId': 'Security ID of company e.g. NSE:7UP',
                'startDate': 'Start date from which you require data e.g. 2017-03-01',
                'endDate': 'End date upto which you require data e.g. 2017-03-31'
        }
    },
    {
        'name': 'company-movaverage',
        'params': {
                'securityId': 'Security ID of company e.g. NSE:7UP',
                'startDate': 'Start date from which you require data e.g. 2017-03-01',
                'endDate': 'End date upto which you require data e.g. 2017-03-31'
        }
    },
    {
        'name': 'currency',
        'params': {
                'country_name': 'Name of country e.g. Tunisia'
        }
    },
    {
        'name': 'currency-rate',
        'params': {
                'curr_code': 'Currency code e.g. TND',
                'base_curr': 'Base currency code e.g. USD',
                'startDate': 'Start date from which you require data e.g. 2017-03-01',
                'endDate': 'End date upto which you require data e.g. 2017-03-31'
        }
    }
]
