from distutils.core import setup
setup(
  name = 'qtx',
  packages = ['qtx'],
  version = '0.1',
  description = 'API client for Quantextive AEX Data Platform',
  author = 'Quantextive',
  author_email = 'api@quantextive.com',
  url = 'https://github.com/quantextive/qtx', #github repo
  download_url = 'https://github.com/quantextive/qtx/archive/0.1.tar.gz',
  keywords = ['africa', 'finance', 'quantextive'],
  classifiers = [],
)

